@@ -18,6 +18,7 @@ import time
 import re
 import signal
 import platform
+import webbrowser
 
 import config
 config.init()
@@ -27,6 +28,7 @@ import util
 
 path = os.path.dirname(os.path.realpath(__file__))
 
+gdb_args = ""
 gdb_executable = "gdb"
 tmux_executable = "tmux"
 terminal_id = "gdb-frontend"
@@ -43,6 +45,11 @@ elif platform.machine()[:3] == "arm":
 
 arg_config = {}
 
+def argHandler_gdbArgs(args):
+    global gdb_args
+
+    gdb_args = args
+
 def argHandler_gdbExecutable(path):
     global gdb_executable
 
@@ -61,6 +68,11 @@ def argHandler_tmuxExecutable(path):
 
     tmux_executable = path
 
+def argHandler_tmuxArgs(args):
+    global tmux_args
+
+    tmux_args = " " + str.strip(args) + " "
+
 def argHandler_terminalId(name):
     global terminal_id
 
@@ -141,6 +153,7 @@ def argHandler_help():
     print("Options:")
     print("  --help, -h:\t\t\t\t\tShows this help message.")
     print("  --version, -v:\t\t\t\tShows version.")
+    print("  --gdb-args=\"ARGS\", -G \"ARGS\":\t\t\tSpecifies GDB command line arguments. (Optional)")
     print("  --gdb-executable=PATH, -g PATH:\t\tSpecifies GDB executable path (Default is \"gdb\" command on PATH environment variable.)")
     print("  --tmux-executable=PATH, -tmux PATH:\t\tSpecifies Tmux executable path (Default is \"tmux\" command on PATH environment variable.)")
     print("  --terminal-id=NAME, -t NAME:\t\t\tSpecifies tmux terminal identifier name (Default is \"gdb-frontend\".)")
@@ -199,6 +212,7 @@ def quit_tmux_gdb():
 
 args = [
     ["--verbose", "-V", argHandler_verbose, False],
+    ["--gdb-args", "-G", argHandler_gdbArgs, True],
     ["--gdb-executable", "-g", argHandler_gdbExecutable, True],
     ["--tmux-executable", "-tmux", argHandler_tmuxExecutable, True],
     ["--terminal-id", "-t", argHandler_terminalId, True],
@@ -308,6 +322,7 @@ try:
             tmux_executable +
             " -f tmux.conf new-session -s " + terminal_id +
             " -d '" + gdb_executable +
+            " " + gdb_args +
             " -ex \"python import sys, os; sys.path.insert(0, \\\""+path+"\\\"); import config, json, base64; config.init(); " +
             "config.setJSON(base64.b64decode(\\\""+base64.b64encode(json.dumps(arg_config).encode()).decode()+"\\\").decode()); import gdbfrontend\"; read;'"
         )
@@ -340,6 +355,11 @@ try:
     if not is_random_port:
         print("Listening on %s: http://%s:%d/" % (config.BIND_ADDRESS, config.HOST_ADDRESS, config.HTTP_PORT))
         print(("Open this address in web browser: \033[0;32;40mhttp://%s:%d/terminal/\033[0m" % (config.HOST_ADDRESS, config.HTTP_PORT)))
+
+        gf_url = "http://%s:%d/terminal/" % (config.HOST_ADDRESS, config.HTTP_PORT)
+
+        if not webbrowser.open(gf_url):
+            os.system("/mnt/c/windows/system32/rundll32.exe url.dll,FileProtocolHandler %s" % gf_url)
         
         gotty.wait()
 
@@ -359,6 +379,7 @@ try:
             " -f tmux.conf send-keys -t " + terminal_id +
             " \"" +
             gdb_executable +
+            " " + gdb_args +
             " -ex \\\"python import sys, os; sys.path.insert(0, '"+path+"'); import config, json, base64; config.init(); " +
             "config.setJSON(base64.b64decode('"+base64.b64encode(json.dumps(arg_config).encode()).decode()+"').decode()); import gdbfrontend\\\"; read;"
             "\" "
@@ -377,6 +398,11 @@ try:
 
         print("Listening on %s: http://%s:%d/" % (config.BIND_ADDRESS, config.HOST_ADDRESS, config.HTTP_PORT))
         print(("Open this address in web browser: \033[0;32;40mhttp://%s:%d/terminal/\033[0m" % (config.HOST_ADDRESS, config.HTTP_PORT)))
+
+        gf_url = "http://%s:%d/terminal/" % (config.HOST_ADDRESS, config.HTTP_PORT)
+
+        if not webbrowser.open(gf_url):
+            os.system("/mnt/c/windows/system32/rundll32.exe url.dll,FileProtocolHandler %s" % gf_url)
         
         gotty.wait()
         gotty.kill()
